@@ -1,9 +1,13 @@
-import logging, sys, copy
+import logging, sys, copy, yaml
 from .images import Image
 
+class _literal(str):
+    pass
+
+def _literal_presenter(dumper, data):
+    return dumper.represent_scalar('tag:yaml.org,2002:str', data, style='|')
+
 class ClusterServiceVersion:
-
-
     LATEST_IMAGE_INDICATOR   = '-latest'
     RELATED_IMAGE_IDENTIFIER = 'olm.relatedImage.'
 
@@ -48,20 +52,30 @@ class ClusterServiceVersion:
     def set_deployments_annotations(self, key=None, value=None):
         """Set key with value passed in for each deployment in the CSV
 
-        Arguments:
-            key {string} -- key being search for in deployment annotations
-            value {string} -- value that will be assigned to the key passed in
+        :param key: Key being search for in deployment annotations
+        :type key: string
+
+        :param value: Value that will be assigned to the key passed in
+        :type value: string
         """
         for d in self.csv['spec']['install']['spec']['deployments']:
             if not 'annotations' in d['spec']['template']['metadata']:
                 continue
             d['spec']['template']['metadata']['annotations'][key] = value
-                    
+
+    def set_container_image_annotation(self, image):
+        """ Set metadata.annotations.containerImage with Image.image passed in
+
+        :param image: Image that will be assigned to metadata.annotations.containerImage
+        :type image: Image
+        """
+        self.csv['metadata']['annotations']['containerImage'] = image.image
+
     def set_version(self, version):
         """Set the target version for the CSV
 
-        Arguments:
-            version {string} -- Target version in semver format X.Y.Z with optional -nnnn for pre-release
+        :param version: Target version in semver format X.Y.Z with optional -nnnn for pre-release
+        :type version: string
         """
         self.version = version
         self.versioned_name = '{}.v{}'.format(self.name, self.version)
@@ -70,8 +84,8 @@ class ClusterServiceVersion:
     def set_replaces(self, replaces):
         """ Set the release that this replaces
 
-        Arguments:
-            replaces {string} -- The versioned name of the csv that this csv replaces
+        :param replaces: The versioned name of the csv that this csv replaces
+        :type replaces: string
         """
         self.replaces = replaces
         self.csv['spec']['replaces'] = self.replaces
@@ -79,8 +93,8 @@ class ClusterServiceVersion:
     def set_image_pullsecret(self, name):
         """ Set the image pull secret for all operator deployment deployments. Overwrites any existing pull secret
 
-        Arguments:
-            name {string|list} -- String or list of strings containing name of the pull secret to add
+        :param name: String or list of strings containing name of the pull secret to add
+        :type name: string, list 
         """
         if isinstance(name, str):
             p = [{'name': name}]
@@ -93,8 +107,8 @@ class ClusterServiceVersion:
     def add_image_pullsecret(self, name):
         """ Add image pull secret for all operator deployment deployments. Existing pull secrets will be kept
 
-        Arguments:
-            name {string|list} -- String or list of strings containing name of the pull secret to add
+        :param name: String or list of strings containing name of the pull secret to add
+        :type name: string, list 
         """
         if isinstance(name, str):
             p = [{'name': name}]
@@ -130,20 +144,20 @@ class ClusterServiceVersion:
                 'name':     r.name,
                 'image':    r.image
             })
-    
+
     def get_owned_crds(self):
         """ Returns a list of owned CustomResourceDefinitions
 
-        Returns:
-            [list [dict]]: List of owned custom resource definitions as dict object
+        :return: List of owned custom resource definitions as dict object
+        :rtype: list
         """
         return self.csv['spec']['customresourcedefinitions']['owned']
 
     def get_updated_csv(self):
         """ Returns the updated CSV object
 
-        Returns:
-            [dict] -- CSV with updated version and image information
+        :return: CSV with updated version and image information
+        :rtype: dict
         """
         # Merge in the updates that are done to Operatorimages and Operandimages
         self._update_operator_container_images()
@@ -151,35 +165,42 @@ class ClusterServiceVersion:
 
         return self.csv
 
+    def get_formatted_csv(self):
+        """ Returns a stringified save ready formatted ClusterServiceVersion
+            This allows maintaining the format of the `alm-examples: |-` block
+        """
+        yaml.add_representer(_literal, _literal_presenter)
+        return yaml.dump(self.get_updated_csv(), default_flow_style=False)
+
     def get_replaces(self):
         """ Return String
 
-        Returns:
-            String -- Returns the csv file name with previous version
+        :return: Returns the csv file name with previous version
+        :rtype: string
         """
         return self.csv['spec']['replaces']
 
     def get_operator_images(self):
         """ Return a list of images used for operator deployment
 
-        Returns:
-            [List of Images] -- Returns a List of Images as defined in Images class
+        :return: Returns a List of Images as defined in Images class
+        :rtype: list
         """
         return self.operator_images
 
     def get_annotation_related_images(self):
         """ Return a list of images found in 'olm.relatedImages.*' deployment annotations
 
-        Returns:
-            [List of Images] -- Returns a List of Images as defined in Images class
+        :return: Returns a List of Images as defined in Images class
+        :rtype: list
         """
         return self.annotation_related_images
 
     def get_operator_deployments(self, api_version='apps/v1', kind='Deployment'):
         """ Return a list of kubernetes deployment objects constructed from the CSV deployments section
 
-        Returns:
-            [List fo Dict] -- List of kubernetes deployment objects
+        :return: List of kubernetes deployment objects
+        :rtype: list
         """
         # Extract the deployment(s)
         deployments = []
@@ -196,7 +217,6 @@ class ClusterServiceVersion:
             
         return deployments
 
-      
     def _update_version_references(self):
         """ Update the version specifc fields based on self.version
         """
@@ -227,7 +247,7 @@ class ClusterServiceVersion:
                 )
                 self.original_operator_images.append(o)
                 self.operator_images.append(o)
-                
+       
     def _get_related_images(self):
         # Capture related images from annotations
         for d in self.csv['spec']['install']['spec']['deployments']:
